@@ -23,15 +23,13 @@ class arima(base_model):
         size = int(len(data) * self._config['train_size'])
         data = data[self._config['label_column']].values
         train, test = data[:size].tolist(), data[size:]
-        predictions = []
-        for t in range(len(test)):
-            model = ARIMA(train,
-                        order=(self._config['lag'], self._config['differencing'], self._config['window_size']))
-            fitted_model = model.fit()
-            predicted = fitted_model.forecast()[0]
-            predictions.append(predicted)
-            train.append(test[t])
 
+        model = ARIMA(train,
+                        order=(self._config['lag'], self._config['differencing'], self._config['window_size']))
+        fitted_model = model.fit()
+        
+        predictions = fitted_model.forecast(steps = len(test))[0]
+        
         print('Evaluating arima performance.')
         self.evaluation(test, predictions)
 
@@ -43,8 +41,12 @@ class arima(base_model):
     
     def predict(self, X_new):
         return self._model.predict(X_new)
+    
+    def predict_next_n(self, step):
+        return self._model.forecast(steps = step)[0]
 
     def autocorrelation(self, data, number_of_time_step = 20):
+        print("Autocorrelation")
         try:
             autocorrelation_plot(data[self._config['label_column']][:number_of_time_step])
             pyplot.show()
@@ -53,6 +55,7 @@ class arima(base_model):
         return None
     
     def partial_autocorrelation(self, data, lags = 20):
+        print("Partial Autocorrelation")
         try:
             plot_pacf(data[self._config['label_column']], lags = lags)
             pyplot.show()
@@ -61,6 +64,7 @@ class arima(base_model):
         return None
     
     def residual_plot(self):
+        print("Residual Plot")
         df = pd.DataFrame(self._model.resid)
         df.plot()
         df.plot(kind='kde')
@@ -69,6 +73,7 @@ class arima(base_model):
         return None
     
     def residual_density_plot(self):
+        print("Residual Density Plot")
         pd.DataFrame(self._model.resid).plot(kind='kde')
         pyplot.show()
         return None        
@@ -76,8 +81,8 @@ class arima(base_model):
     
 if __name__ == "__main__":
     import pandas as pd
-    data = pd.read_csv("../../development/Feature_Mart/feature_mart_merged_1.csv")
-    data = data
+    data = pd.read_csv("../../../feature_mart.csv")
+    data = data[-100:]
     
     user_config = {'lag' : 2,
                    'differencing' : 0,
@@ -86,9 +91,9 @@ if __name__ == "__main__":
                    'train_size' : 0.8,
                    'seed' : 33}
     arima_shell = arima(user_config)
-    data = data[-150:]
-    arima_shell.autocorrelation(data)
-    arima_shell.partial_autocorrelation(data)
+##    arima_shell.autocorrelation(data)
+##    arima_shell.partial_autocorrelation(data)
     arima_shell.build_model(data)
-    arima_shell.residual_plot()
+    print(arima_shell.predict_next_n(10))
+##    arima_shell.residual_plot()
     
